pub fn callable_virtual_impl<'a>(
def: &'a FullDef<'_>,
target_kind: ClosureKind,
) -> &'a VirtualTraitImplExpand description
The built-in Fn* impl of the given kind that we generate for this closure or function item.
pub fn callable_virtual_impl<'a>(
def: &'a FullDef<'_>,
target_kind: ClosureKind,
) -> &'a VirtualTraitImplThe built-in Fn* impl of the given kind that we generate for this closure or function item.